@@ -13,24 +13,13 @@ Dialog boxes used to edit data sets:
     DataSetEditDialog
     DataSetGroupEditDialog
     DataSetShowDialog
-    
+
 ...and layouts:
     GroupItem
     DataSetEditLayout
     DataSetShowLayout
 """
 
-from __future__ import print_function
-
-try:
-    # PyQt4 4.3.3 on Windows (static DLLs) with py2exe installed:
-    # -> pythoncom must be imported first, otherwise py2exe's boot_com_servers
-    #    will raise an exception ("Unable to load DLL [...]") when calling any
-    #    of the QFileDialog static methods (getOpenFileName, ...)
-    import pythoncom
-except ImportError:
-    pass
-
 from qtpy.QtWidgets import (
     QDialog,
     QMessageBox,
@@ -51,9 +40,9 @@ from qtpy.compat import getopenfilename, getopenfilenames, getsavefilename
 
 from guidata.configtools import get_icon
 from guidata.config import _
-from qtpy.py3compat import to_text_string, is_text_string
 
 from guidata.dataset.datatypes import BeginGroup, EndGroup, GroupItem, TabGroupItem
+from guidata.qthelpers import win32_fix_title_bar_background
 
 
 class DataSetEditDialog(QDialog):
@@ -65,6 +54,7 @@ class DataSetEditDialog(QDialog):
         self, instance, icon="", parent=None, apply=None, wordwrap=True, size=None
     ):
         QDialog.__init__(self, parent)
+        win32_fix_title_bar_background(self)
         self.wordwrap = wordwrap
         self.apply_func = apply
         self.layout = QVBoxLayout()
@@ -123,7 +113,7 @@ class DataSetEditDialog(QDialog):
 
     def layout_factory(self, instance, grid):
         """A factory method that produces instances of DataSetEditLayout
-        
+
         or derived classes (see DataSetShowDialog)
         """
         return DataSetEditLayout(self, instance, grid)
@@ -202,11 +192,14 @@ class DataSetEditLayout(object):
         """Register a factory for a new item_type"""
         cls._widget_factory[item_type] = factory
 
-    def __init__(self, parent, instance, layout, items=None, first_line=0):
+    def __init__(
+        self, parent, instance, layout, items=None, first_line=0, change_callback=None
+    ):
         self.parent = parent
         self.instance = instance
         self.layout = layout
         self.first_line = first_line
+        self.change_callback = change_callback
         self.widgets = []
         self.linenos = {}  # prochaine ligne à remplir par colonne
         self.items_pos = {}
@@ -262,21 +255,45 @@ class DataSetEditLayout(object):
                 for item in items
             ]
         )
+
+        # Check if specified rows are consistent
+        sorted_items = [None] * len(items)
+        rows = []
+        other_items = []
+        for item in items:
+            row = item.get_prop("display", "row")
+            if row is not None:
+                if row in rows:
+                    raise ValueError(
+                        "Duplicate row index (%d) for item %r" % (row, item._name)
+                    )
+                if row < 0 or row >= len(items):
+                    raise ValueError(
+                        "Out of range row index (%d) for item %r" % (row, item._name)
+                    )
+                rows.append(row)
+                sorted_items[row] = item
+            else:
+                other_items.append(item)
+        for idx, line in enumerate(sorted_items[:]):
+            if line is None:
+                sorted_items[idx] = other_items.pop(0)
+
         self.items_pos = {}
         line = self.first_line - 1
         last_item = [-1, 0, colmax]
-        for item in items:
-            beg = item.get_prop("display", "col")
-            span = item.get_prop("display", "colspan")
-            if span is None:
-                span = colmax - beg + 1
-            if beg <= last_item[1]:
+        for item in sorted_items:
+            col = item.get_prop("display", "col")
+            colspan = item.get_prop("display", "colspan")
+            if colspan is None:
+                colspan = colmax - col + 1
+            if col <= last_item[1]:
                 # on passe à la ligne si la colonne de debut de cet item
                 #  est avant la colonne de debut de l'item précédent
                 line += 1
             else:
-                last_item[2] = beg - last_item[1]
-            last_item = [line, beg, span]
+                last_item[2] = col - last_item[1]
+            last_item = [line, col, colspan]
             self.items_pos[item] = last_item
 
         for item in items:
@@ -325,6 +342,11 @@ class DataSetEditLayout(object):
             if widget is not except_this_one:
                 widget.get()
 
+    def widget_value_changed(self):
+        """Method called when any widget's value has changed"""
+        if self.change_callback is not None:
+            self.change_callback()
+
 
 # Enregistrement des correspondances avec les widgets
 from guidata.dataset.qtitemwidgets import (
@@ -514,6 +536,7 @@ class DataSetShowGroupBox(QGroupBox):
 
     def __init__(self, label, klass, wordwrap=False, **kwargs):
         QGroupBox.__init__(self, label)
+        self.apply_button = None
         self.klass = klass
         self.dataset = klass(**kwargs)
         self.layout = QVBoxLayout()
@@ -541,7 +564,7 @@ class DataSetShowGroupBox(QGroupBox):
 class DataSetEditGroupBox(DataSetShowGroupBox):
     """
     Group box widget including a DataSet
-    
+
     label: group box label (string)
     klass: guidata.DataSet class
     button_text: action button text (default: "Apply")
@@ -567,16 +590,22 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
                 button_text = _("Apply")
             if button_icon is None:
                 button_icon = get_icon("apply.png")
-            elif is_text_string(button_icon):
+            elif isinstance(button_icon, str):
                 button_icon = get_icon(button_icon)
-            apply_btn = QPushButton(button_icon, button_text, self)
-            apply_btn.clicked.connect(self.set)
+            self.apply_button = applyb = QPushButton(button_icon, button_text, self)
+            applyb.clicked.connect(self.set)
             layout = self.edit.layout
-            layout.addWidget(apply_btn, layout.rowCount(), 0, 1, -1, Qt.AlignRight)
+            layout.addWidget(applyb, layout.rowCount(), 0, 1, -1, Qt.AlignRight)
 
     def get_edit_layout(self):
         """Return edit layout"""
-        return DataSetEditLayout(self, self.dataset, self.grid_layout)
+        return DataSetEditLayout(
+            self, self.dataset, self.grid_layout, change_callback=self.change_callback
+        )
+
+    def change_callback(self):
+        """Method called when any widget's value has changed"""
+        self.set_apply_button_state(True)
 
     def set(self):
         """Update data item values from layout contents"""
@@ -584,11 +613,16 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
             if widget.is_active() and widget.check():
                 widget.set()
         self.SIG_APPLY_BUTTON_CLICKED.emit()
+        self.set_apply_button_state(False)
+
+    def set_apply_button_state(self, state):
+        """Set apply button enable/disable state"""
+        if self.apply_button is not None:
+            self.apply_button.setEnabled(state)
 
     def child_title(self, item):
         """Return data item title combined with QApplication title"""
         app_name = QApplication.applicationName()
         if not app_name:
-            app_name = to_text_string(self.title())
+            app_name = str(self.title())
         return "%s - %s" % (app_name, item.label())
-
