@@ -20,25 +20,8 @@ SHOW = True  # Show test in GUI-based test launcher
 
 import tempfile, atexit, shutil, datetime, numpy as np
 
-from guidata.dataset.datatypes import DataSet, BeginGroup, EndGroup
-from guidata.dataset.dataitems import (
-    FloatItem,
-    IntItem,
-    BoolItem,
-    ChoiceItem,
-    MultipleChoiceItem,
-    ImageChoiceItem,
-    FilesOpenItem,
-    StringItem,
-    TextItem,
-    ColorItem,
-    FileSaveItem,
-    FileOpenItem,
-    DirectoryItem,
-    FloatArrayItem,
-    DateItem,
-    DateTimeItem,
-)
+import guidata.dataset.datatypes as gdt
+import guidata.dataset.dataitems as gdi
 
 
 # Creating temporary files and registering cleanup functions
@@ -50,7 +33,7 @@ FILE_CSV = tempfile.NamedTemporaryFile(suffix=".csv", dir=TEMPDIR)
 atexit.register(FILE_CSV.close)
 
 
-class TestParameters(DataSet):
+class TestParameters(gdt.DataSet):
     """
     DataSet test
     The following text is the DataSet 'comment': <br>Plain text or
@@ -58,27 +41,29 @@ class TestParameters(DataSet):
     as well as special characters (α, β, γ, δ, ...)
     """
 
-    dir = DirectoryItem("Directory", TEMPDIR)
-    fname = FileOpenItem("Open file", ("csv", "eta"), FILE_CSV.name)
-    fnames = FilesOpenItem("Open files", "csv", FILE_CSV.name)
-    fname_s = FileSaveItem("Save file", "eta", FILE_ETA.name)
-    string = StringItem("String")
-    text = TextItem("Text")
-    float_slider = FloatItem(
+    dir = gdi.DirectoryItem("Directory", TEMPDIR)
+    fname = gdi.FileOpenItem("Open file", ("csv", "eta"), FILE_CSV.name)
+    fnames = gdi.FilesOpenItem("Open files", "csv", FILE_CSV.name)
+    fname_s = gdi.FileSaveItem("Save file", "eta", FILE_ETA.name)
+    string = gdi.StringItem("String")
+    text = gdi.TextItem("Text")
+    float_slider = gdi.FloatItem(
         "Float (with slider)", default=0.5, min=0, max=1, step=0.01, slider=True
     )
-    integer = IntItem("Integer", default=5, min=3, max=16, slider=True).set_pos(col=1)
-    dtime = DateTimeItem("Date/time", default=datetime.datetime(2010, 10, 10))
-    date = DateItem("Date", default=datetime.date(2010, 10, 10)).set_pos(col=1)
-    bool1 = BoolItem("Boolean option without label")
-    bool2 = BoolItem("Boolean option with label", "Label")
-    _bg = BeginGroup("A sub group")
-    color = ColorItem("Color", default="red")
-    choice = ChoiceItem(
+    integer = gdi.IntItem("Integer", default=5, min=3, max=16, slider=True).set_pos(
+        col=1
+    )
+    dtime = gdi.DateTimeItem("Date/time", default=datetime.datetime(2010, 10, 10))
+    date = gdi.DateItem("Date", default=datetime.date(2010, 10, 10)).set_pos(col=1)
+    bool1 = gdi.BoolItem("Boolean option without label")
+    bool2 = gdi.BoolItem("Boolean option with label", "Label")
+    _bg = gdt.BeginGroup("A sub group")
+    color = gdi.ColorItem("Color", default="red")
+    choice = gdi.ChoiceItem(
         "Single choice 1",
         [("16", "first choice"), ("32", "second choice"), ("64", "third choice")],
     )
-    mchoice2 = ImageChoiceItem(
+    mchoice2 = gdi.ImageChoiceItem(
         "Single choice 2",
         [
             ("rect", "first choice", "gif.png"),
@@ -86,15 +71,15 @@ class TestParameters(DataSet):
             ("qcq", "third choice", "file.png"),
         ],
     )
-    _eg = EndGroup("A sub group")
-    floatarray = FloatArrayItem(
+    _eg = gdt.EndGroup("A sub group")
+    floatarray = gdi.FloatArrayItem(
         "Float array", default=np.ones((50, 5), float), format=" %.2e "
     ).set_pos(col=1)
-    mchoice3 = MultipleChoiceItem("MC type 1", [str(i) for i in range(12)]).horizontal(
-        4
-    )
+    mchoice3 = gdi.MultipleChoiceItem(
+        "MC type 1", [str(i) for i in range(12)]
+    ).horizontal(4)
     mchoice1 = (
-        MultipleChoiceItem(
+        gdi.MultipleChoiceItem(
             "MC type 2", ["first choice", "second choice", "third choice"]
         )
         .vertical(1)
