@@ -958,10 +958,6 @@ class BaseTableView(QTableView):
         """Return array's ndim"""
         raise NotImplementedError
 
-    def oedit(self, key):
-        """Edit item"""
-        raise NotImplementedError
-
     def plot(self, key, funcname):
         """Plot item"""
         raise NotImplementedError
@@ -1447,13 +1443,6 @@ class CollectionsEditorTableView(BaseTableView):
         data = self.model.get_data()
         return data[key].ndim
 
-    def oedit(self, key):
-        """Edit item"""
-        data = self.model.get_data()
-        from guidata.widgets.objecteditor import oedit
-
-        oedit(data[key])
-
     def plot(self, key, funcname):
         """Plot item"""
         data = self.model.get_data()
